@@ -2,5 +2,6 @@ from dataconf.utils import dump
 from dataconf.utils import dumps
 from dataconf.utils import load
 from dataconf.utils import loads
+from dataconf.version import __version__
 
-__all__ = ["load", "loads", "dump", "dumps"]
+__all__ = ["load", "loads", "dump", "dumps", "__version__"]
